Replace eof by error in receivers/filters/writers.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index be5f7454532c77899af4957668d0c809bff96668..71c666d663bdb2f94b8af236bb7385b18cc4ac24 100644 (file)
--- a/write.h
+++ b/write.h
@@ -10,7 +10,7 @@
 enum writer_enum {WRITER_ENUM};
 
 /**
- * decbribes one running instance of a writer
+ * Describes one running instance of a writer.
  */
 struct writer_node {
        /** points to the writer structure associated with this node */
@@ -55,7 +55,7 @@ struct writer {
         *
         * This function should perform any work necessary to write the incoming
         * stream. If To this aim, it may allocate its private data structure and store
-        * a pointer to that structure via the given writer_node paramenter.
+        * a pointer to that structure via the given writer_node parameter.
         */
        int (*open)(struct writer_node *);
        /**
@@ -70,7 +70,7 @@ struct writer {
        int (*pre_select)(struct sched *s, struct writer_node *wn);
        /**
         * Called from the post_select function of the wng task. It must keep
-        * track of the the number of bytes consumed from the wng's buffer via
+        * track of the number of bytes consumed from the wng's buffer via
         * the wn->written variable (which may be modified by the wng handling
         * functions). This function must return positive on success and
         * negative on errors.
@@ -101,10 +101,10 @@ struct writer_node_group {
        struct writer_node *writer_nodes;
        /** the maximum of the chunk_bytes values of the writer nodes in this group */
        size_t max_chunk_bytes;
-       /** non-zero if end of file was encountered by the feeding task */
-       int *input_eof;
-       /** non-zero if end of file was encountered */
-       int eof;
+       /** Non-zero if an error or end of file was encountered by the feeding task. */
+       int *input_error;
+       /** Non-zero if an error occurred or end of file was encountered. */
+       int error;
        /** current output buffer */
        char *buf;
        /** number of bytes loaded in the output buffer */